import { Logger } from '../logger.js';

/**
 * WhoTracks.Me
 * https://whotracks.me/
 *
 * Copyright 2017-present Ghostery GmbH. All rights reserved.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0
 */


// Pacemaker is a service which allows to schedule tasks (either as intervals or
// timeouts) while doing its best to not wake-up the browser too often. To this
// end, it offers a few common intervals (e.g.: every minute, every hour,
// etc.) and makes sure that all the tasks are triggered at the same time. It
// also tries to adapt its own frequency depending on registered tasks to
// trigger as rarely as possible while respecting the contract. As a
// consequence, if there is no task registered, the pacemaker will do nothing.
//
// It is possible to schedule tasks at any time, but this is not recommended. To
// make sure the efficiency is maximal, you should pick a pre-defined method
// like `everyFewMinutes` (instead of `register`) and choose the maximum time
// which fits your use-case.
//
// Here are a few examples:
//
// 1. You need to update a config fetched from CDN and it does not change more
// than once an hour, then it's recommended to use `pacemaker.everyHour()`.
//
// 2. You need to run a check on the state of your module every few seconds (and
// it does not matter exactly how many seconds as long as it's less or equal to
// 10), then you should use `pacemaker.everyFewSeconds()`.

Logger.get('pacemaker', { level: 'log' });
